@@ -43,44 +43,54 @@ use crate::{
 /// # Ok(())
 /// # }
 /// ```
-pub struct Reader<R>
-where
-    R: AsyncRead,
-{
-    inner: bgzf::AsyncReader<R>,
+pub struct Reader<R> {
+    inner: R,
 }
 
 impl<R> Reader<R>
 where
     R: AsyncRead + Unpin,
 {
-    /// Creates an async BAM reader builder.
+    /// Returns a reference to the underlying reader.
     ///
     /// # Examples
     ///
     /// ```
     /// use noodles_bam as bam;
     /// let data = [];
-    /// let builder = bam::AsyncReader::builder(&data[..]);
-    /// let reader = builder.build();
+    /// let reader = bam::AsyncReader::from(&data[..]);
+    /// assert!(reader.get_ref().is_empty());
     /// ```
-    pub fn builder(inner: R) -> Builder<R> {
-        Builder::new(inner)
+    pub fn get_ref(&self) -> &R {
+        &self.inner
     }
 
-    /// Creates an async BAM reader.
+    /// Returns a mutable reference to the underlying reader.
     ///
     /// # Examples
     ///
     /// ```
     /// use noodles_bam as bam;
     /// let data = [];
-    /// let reader = bam::AsyncReader::new(&data[..]);
+    /// let mut reader = bam::AsyncReader::from(&data[..]);
+    /// assert!(reader.get_mut().is_empty());
     /// ```
-    pub fn new(reader: R) -> Self {
-        Self {
-            inner: bgzf::AsyncReader::new(reader),
-        }
+    pub fn get_mut(&mut self) -> &mut R {
+        &mut self.inner
+    }
+
+    /// Returns the underlying reader.
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use noodles_bam as bam;
+    /// let data = [];
+    /// let reader = bam::AsyncReader::from(&data[..]);
+    /// assert!(reader.into_inner().is_empty());
+    /// ```
+    pub fn into_inner(self) -> R {
+        self.inner
     }
 
     /// Reads the raw SAM header.
@@ -222,6 +232,38 @@ where
             },
         ))
     }
+}
+
+impl<R> Reader<bgzf::AsyncReader<R>>
+where
+    R: AsyncRead + Unpin,
+{
+    /// Creates an async BAM reader builder.
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use noodles_bam as bam;
+    /// let data = [];
+    /// let builder = bam::AsyncReader::builder(&data[..]);
+    /// let reader = builder.build();
+    /// ```
+    pub fn builder(inner: R) -> Builder<R> {
+        Builder::new(inner)
+    }
+
+    /// Creates an async BAM reader.
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use noodles_bam as bam;
+    /// let data = [];
+    /// let reader = bam::AsyncReader::new(&data[..]);
+    /// ```
+    pub fn new(reader: R) -> Self {
+        Self::from(bgzf::AsyncReader::new(reader))
+    }
 
     /// Returns the current virtual position of the underlying BGZF reader.
     ///
@@ -242,7 +284,7 @@ where
     }
 }
 
-impl<R> Reader<R>
+impl<R> Reader<bgzf::AsyncReader<R>>
 where
     R: AsyncRead + AsyncSeek + Unpin,
 {
@@ -315,6 +357,12 @@ where
     }
 }
 
+impl<R> From<R> for Reader<R> {
+    fn from(inner: R) -> Self {
+        Self { inner }
+    }
+}
+
 async fn read_magic<R>(reader: &mut R) -> io::Result<()>
 where
     R: AsyncRead + Unpin,
