@@ -45,15 +45,13 @@ where
     /// let data = [];
     /// let reader = bam::AsyncReader::builder(&data[..]).build();
     /// ```
-    pub fn build(self) -> Reader<R> {
+    pub fn build(self) -> Reader<bgzf::AsyncReader<R>> {
         let mut builder = bgzf::AsyncReader::builder(self.inner);
 
         if let Some(worker_count) = self.worker_count {
             builder = builder.set_worker_count(worker_count);
         }
 
-        Reader {
-            inner: builder.build(),
-        }
+        Reader::from(builder.build())
     }
 }
