@@ -171,12 +171,13 @@ where
 
 async fn write_mapping_quality<W>(
     writer: &mut W,
-    mapping_quality: sam::record::MappingQuality,
+    mapping_quality: Option<sam::record::MappingQuality>,
 ) -> io::Result<()>
 where
     W: AsyncWrite + Unpin,
 {
-    let mapq = u8::from(mapping_quality);
+    use sam::record::mapping_quality::MISSING;
+    let mapq = mapping_quality.map(u8::from).unwrap_or(MISSING);
     writer.write_u8(mapq).await
 }
 
